"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoDbAppender = exports.configure = void 0;
const mongodb = require("mongodb");
const get_mongo_collection_1 = require("./sources/get-mongo-collection");
const is_mongo_definition_1 = require("./sources/helpers/is-mongo-definition");
/** @description local variable to save connection to database */
let dbConnection;
/**
 * Exported configuration function to init appender
 *
 * @param {MongoAppenderConfiguration} config Configuration for mongo
 * @param {log4js.LayoutsParam} layouts log4js layouts collection
 */
const configure = (config, layouts, findAppender, levels) => {
    return Log(config, layouts, findAppender, levels);
};
exports.configure = configure;
/**
 * @description Exported AppenderModule function to init
 *
 * @export
 * @param {RestAppenderConfig} config Configuration for mongo
 * @returns
 */
exports.MongoDbAppender = {
    configure: exports.configure,
};
/**
 * @description Base appender function
 *
 * @param {MongoAppenderConfiguration} config Configuration for mongo
 * @param {log4js.LayoutsParam} layouts log4js layouts collection
 * @return {*}
 */
function Log(config, layouts, findAppender, levels) {
    findAppender = findAppender;
    levels = levels;
    const logPrefix = `${__filename}[${Log.name}]:`;
    let layout = undefined;
    if (config.layout) {
        if (layouts) {
            layout = layouts.layout(config.layout.type, config.layout);
        }
    }
    return (loggingEvent) => {
        let logData = loggingEvent;
        if (layout) {
            logData = layout(logData);
        }
        (0, get_mongo_collection_1.getMongoCollection)(dbConnection, config, (errConnection, respConnection) => {
            if (!errConnection && respConnection) {
                dbConnection = respConnection;
                (() => __awaiter(this, void 0, void 0, function* () {
                    try {
                        const respInsert = yield dbConnection.insertOne(logData);
                        if ((0, is_mongo_definition_1.isMongoDefinition)(config.mongoSetting)) {
                            if (config.mongoSetting.logLevel ==
                                mongodb.LoggerLevel.DEBUG) {
                                console.debug(logPrefix, JSON.stringify(respInsert));
                            }
                        }
                    }
                    catch (errInsert) {
                        console.error(logPrefix, errInsert);
                    }
                }))();
            }
        });
    };
}
//# sourceMappingURL=index.js.map