"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMongoCollection = void 0;
const get_mongo_db_1 = require("./get-mongo-db");
const is_mongo_definition_1 = require("./helpers/is-mongo-definition");
/**
 * @description Init mongodb collection
 *
 * @export
 * @param {(mongodb.Collection | undefined)} dbCollection saved connection
 * @param {MongoAppenderConfiguration} config Configuration to mongo
 * @param {((err: Error | undefined, resp: mongodb.Collection | undefined) => void)} cb
 */
function getMongoCollection(dbCollection, config, cb) {
    if (dbCollection) {
        cb(undefined, dbCollection);
    }
    else if (config) {
        if ((0, is_mongo_definition_1.isMongoDefinition)(config.mongoSetting)) {
            (0, get_mongo_db_1.default)(config.mongoSetting, (err, collection) => {
                if (err || !collection) {
                    cb(err, undefined);
                }
                else {
                    cb(undefined, collection);
                }
            });
        }
        else {
            const result = config.mongoSetting.client
                .db(config.mongoSetting.database)
                .collection(config.mongoSetting.collection);
            cb(undefined, result);
        }
    }
    else {
        cb(new Error('No config or collection definned!'), undefined);
    }
}
exports.getMongoCollection = getMongoCollection;
//# sourceMappingURL=get-mongo-collection.js.map