"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeMongoDb = void 0;
const mongodb = require("mongodb");
let client;
let db;
let collection;
const MongoClient = mongodb.MongoClient;
/**
 * @description It keeps MongoDb connection in RAM.
 *
 * @export
 * @param {IMongoDefinition} config  Configuration to mongo
 * @param {((
 *         err: Error | undefined,
 *         collection: mongodb.Collection | undefined
 *     ) => void)} cb Callback function with error and db.
 */
function getMongoDb(config, cb) {
    if (client) {
        cb(undefined, collection);
    }
    else {
        (() => __awaiter(this, void 0, void 0, function* () {
            try {
                const newClient = yield MongoClient.connect(config.url, config.options);
                client = newClient;
                db = client.db(config.database);
                collection = db.collection(config.collection);
                cb(undefined, collection);
            }
            catch (err) {
                const error = err;
                const logErr = {
                    error: error,
                    extraInfo: {
                        function: `${__filename}[${getMongoDb.name}]`,
                        config: config,
                    },
                };
                console.error(logErr);
                cb(error, undefined);
            }
        }))();
    }
}
exports.default = getMongoDb;
/**
 * @description Close MongoDb connection
 * @export
 * @param {() => void} cb
 */
function closeMongoDb(cb) {
    if (client) {
        client.close(() => {
            cb();
        });
    }
    else {
        cb();
    }
}
exports.closeMongoDb = closeMongoDb;
//# sourceMappingURL=get-mongo-db.js.map