import { jsonLayoutConfig } from 'log4js-layouts';
import * as mongodb from 'mongodb';
/**
 * @description Mongo configuration definition
 *
 * @export
 * @interface MongoAppenderConfiguration
 */
export interface MongoAppenderConfiguration {
    /** @description Log4js type */
    type: 'log4js-db-mongodb';
    /** Parent connection to mongoDb or connection properties to mongoDb*/
    mongoSetting: IMongoClient | IMongoDefinition;
    /** @description Layout definition */
    layout: jsonLayoutConfig;
}
/**
 * @description Mongo connection with the database and collection
 *
 * @export
 * @interface IMongoClient
 */
export interface IMongoClient {
    /** @description Mongo client for access to db*/
    client: mongodb.MongoClient;
    /** @description Mongo database to write */
    database: string;
    /** @description Mongo collection to write */
    collection: string;
}
/**
 * @description Mongo connection definition
 *
 * @export
 * @interface IMongoDefinition
 */
export interface IMongoDefinition {
    /** @description Mongo connection string: MONGO_URL="mongodb+srv://bull-wsttp.mongodb.net/" */
    url: string;
    /** @description Mongo settings */
    options: mongodb.MongoClientOptions;
    /** @description Mongo database to write */
    database: string;
    /** @description Mongo collection to write */
    collection: string;
    /** @description Mongo debug level */
    logLevel: mongodb.LoggerLevel;
}
